@@ -21,13 +21,13 @@
 class K3bMainWindow;
 class K3bFileTreeView;
 class TQFrame;
-class KAction;
+class TDEAction;
 
 
 class K3bSidePanel : public TQToolBox
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bSidePanel( K3bMainWindow*, TQWidget* parent = 0, const char* name = 0 );
@@ -44,7 +44,7 @@ class K3bSidePanel : public TQToolBox
   K3bFileTreeView* m_fileTreeView;
 
   TQFrame* createPanel();
-  void addButton( TQFrame* frame, KAction* action );
+  void addButton( TQFrame* frame, TDEAction* action );
 };
 
 #endif
